package com.hp.user.service.controller;

import com.hp.user.client.entity.CustomerCompanyVO;
import com.hp.user.client.service.CustomerCompanyService;
import com.hp.user.utils.HttpResult;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@Api(tags = "企业/服务商API接口")
@RestController
@RequestMapping("/company")
public class CompanyController {
    @Autowired
    private CustomerCompanyService customerCompanyService;
    /**
     * 添加企业
     */
    @ApiOperation(value = "新增企业", notes = "新增企业", httpMethod = "POST")
    @PostMapping("/addCompany")
    public HttpResult addCompany(@RequestBody CustomerCompanyVO company){
        company.setCustomerId(123L);
        boolean flag=customerCompanyService.insert(company);
        if(flag) return HttpResult.success(company.getCustomerId());
        else return HttpResult.fail();
    }

    /**
     * 更新企业信息
     */
    @ApiOperation(value = "更新企业信息", notes = "更新企业信息", httpMethod = "POST")
    @PostMapping("/updateCompany")
    public HttpResult updateCompany(@RequestBody CustomerCompanyVO company){
        boolean flag=customerCompanyService.update(company);
        if(flag) return HttpResult.success();
        else return HttpResult.fail();
    }

    /**
     * 根据企业Id删除企业
     * @param companyId 企业Id
     */
    @ApiOperation(value = "删除企业", notes = "删除企业", httpMethod = "GET")
    @GetMapping("/deleteCompanyByCompanyId")
    public HttpResult deleteCompanyByCompanyId(@RequestParam String companyId){
        boolean flag=customerCompanyService.delete(Long.parseLong(companyId));
        if(flag) return HttpResult.success();
        else return HttpResult.fail();
    }

    /**
     * 根据企业Id查询某企业信息
     * @param companyId 企业Id
     */
    @ApiOperation(value="根据企业Id查询某企业信息")
    @GetMapping("/queryCompanyByCompanyId")
    public CustomerCompanyVO queryCompanyByCompanyId(@RequestParam String companyId){
        return customerCompanyService.queryCompanyByCompanyId(Long.parseLong(companyId));
    }

    /**
     * 查询所有企业基本信息
     */
    @GetMapping("/queryAllCompany")
    public void queryAllCompany(){

    }

    /**
     * 查询某企业的所有用户
     * @param companyId 企业Id
     */
    @GetMapping("/queryAllUserOfCompany")
    public void queryAllUserOfCompany(String companyId){

    }

    /**
     * 关联某企业与某用户
     * @param companyId 企业Id
     * @param userId 用户Id
     */
    @GetMapping("/associateCompanyAndUser")
    public void associateCompanyAndUser(String companyId,String userId){

    }

    /**
     * 解除某企业与某用户的关联
     * @param companyId 企业Id
     * @param userId 用户Id
     */
    @GetMapping("/dissociateCompanyAndUser")
    public void dissociateCompanyAndUser(String companyId,String userId){

    }
}
